@@ -17,12 +17,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Autoload.py,v 1.4 1999/09/24 07:21:05 gobry Exp $
+# $Id: Autoload.py,v 1.1.1.1 1999/11/22 13:29:30 fredgo Exp $
 
 import os, string, re
 
 class Loader:
-    """ An object containing the description of a loadable object """
+    ''' An object containing the description of a loadable object '''
     
     def __init__ (self, name, regexp, module,
                   info = None, data = None):
@@ -68,7 +68,7 @@ class Loader:
 __loaders = {}
 
 def preregister (group, name, module, regexp = None, info = None):
-    """ Register for autoloading """
+    ''' Register for autoloading '''
 
     # get info from the given group
     if __loaders.has_key (group):
@@ -85,7 +85,7 @@ def preregister (group, name, module, regexp = None, info = None):
 
 
 def register (group, name, data = None):
-    """ Register when the module is actually loaded """
+    ''' Register when the module is actually loaded '''
 
     mod = get_by_name (group, name, 0) or preregister (group, name, None)
     mod.is_loaded ()
@@ -95,7 +95,7 @@ def register (group, name, data = None):
 
 
 def get_by_regexp (group, key):
-    """ Returns a loaded module according to a key that it must match """
+    ''' Returns a loaded module according to a key that it must match '''
 
     if not __loaders.has_key (group):
         return None
@@ -110,7 +110,7 @@ def get_by_regexp (group, key):
 
 
 def get_by_name (group, name, load = 1):
-    """ Returns a loaded module according to its name """
+    ''' Returns a loaded module according to its name '''
     
     if not __loaders.has_key (group):
         return None
@@ -127,11 +127,11 @@ def get_by_name (group, name, load = 1):
 
 
 def available (group):
-    """ Returns the list of available modules in a group """
+    ''' Returns the list of available modules in a group '''
     
     return map (lambda x: x.name, __loaders [group].values ())
 
 
 def groups ():
-    """ Returns a list of the groups """
+    ''' Returns a list of the groups '''
     return __loaders.keys ()
