@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Base.py,v 1.30 1999/09/30 15:21:04 gobry Exp $
+# $Id: Base.py,v 1.1.1.1 1999/11/22 13:29:30 fredgo Exp $
 
 from string import *
 import re
@@ -26,13 +26,13 @@ from types import *
 
 from Pyblio import Config
 
-""" This Module contains the base classes one might want to inherit
-from in order to provide a new database format """
+''' This Module contains the base classes one might want to inherit
+from in order to provide a new database format '''
 
 
 		
 def format (string, width, first, next):
-	"Format a string on a given width"
+	''' Format a string on a given width '''
 
 	out = []
 	current = first
@@ -63,16 +63,15 @@ def format (string, width, first, next):
 
 
 class Key:
-	"""
-	A special key that embeds both database and database key
-	Such a key is expected to be completely unique among the whole
-	program and should be the reliable information checked to see
-	if two entries are the same.
 
-	The .base field is public and is the database from which the
-	actual entry can be recovered, whereas the .key is private to
-	the database itself.
-	"""
+	''' A special key that embeds both database and database
+	key Such a key is expected to be completely unique among the
+	whole program and should be the reliable information checked
+	to see if two entries are the same.
+
+	The .base field is the database name from which the actual
+	entry can be recovered, whereas the .key field is the name in
+	the database itself.  '''
 	
 	def __init__ (self, base, key):
 		if type (key) is InstanceType:
@@ -110,7 +109,7 @@ class Key:
 
 
 class Entry:
-	"""
+	'''
 	A database entry. It behaves like a dictionnary, which
 	returns an instance of Description for each key. For example,
 	entry ['author'] is expected to return a Types.AuthorGroup
@@ -125,12 +124,11 @@ class Entry:
 
 	The entry.type is an instance of Types.EntryDescription. It
 	links the field names with their type.
-	"""
+	'''
 	
 	id = 'VirtualEntry'
 
-	def __init__ (self, key, name, type = None, dict = None):
-		self.name = name
+	def __init__ (self, key, type = None, dict = None):
 		self.type = type
 		self.__dict = dict or {}
 		self.key    = key
@@ -140,8 +138,8 @@ class Entry:
 
 
 	def keys (self):
-		""" returns all the keys for this entry (counting
-		those who belong to crossreferences) """
+		''' returns all the keys for this entry (counting
+		those who belong to crossreferences) '''
 		perso = self.__dict.keys ()
 		if self.crossref:
 			for k in self.crossref.keys ():
@@ -152,14 +150,14 @@ class Entry:
 
 			
 	def personal_keys (self):
-		""" Returns the keys that are actually defined by the entry,
-		and not by its crossreferences """
+		''' Returns the keys that are actually defined by the entry,
+		and not by its crossreferences '''
 		return self.__dict.keys ()
 
 	
 	def is_personal (self, key):
-		""" indicates if a given field is defined by the entry or
-		one of its crossreferences """
+		''' indicates if a given field is defined by the entry or
+		one of its crossreferences '''
 		if self.__dict.has_key (key):
 			return 1
 		return 0
@@ -175,7 +173,7 @@ class Entry:
 
 
 	def text (self, key):
-		""" return text with indication of convertion loss """
+		''' return text with indication of convertion loss '''
 		
 		if self.is_personal (key):
 			return self.__dict [key], 0
@@ -188,24 +186,24 @@ class Entry:
 
 	
 	def get_native (self, key):
-		""" returns the field in its native form """
+		''' returns the field in its native form '''
 		
 		return self [key]
 
 
 	def set_native (self, key, value):
-		""" sets the field in its native form """
+		''' sets the field in its native form '''
 		
 		self [key] = value
 		return
 	
 	def __getitem__ (self, key):
-		""" return text representation of a field """
+		''' return text representation of a field '''
 		
 		return self.text (key) [0]
 	
 	def foreach (self, function, argument = None):
-		""" To provide compatibility with ref """
+		''' To provide compatibility with ref '''
 		
 		function (self, argument)
 		return
@@ -222,12 +220,12 @@ class Entry:
 
 	
 	def __add__ (self, other):
-		""" Merges two entries, key by key """
+		''' Merges two entries, key by key '''
 
-		ret = Entry (self.key, self.name, self.type, {})
+		ret = Entry (self.key, self.type, {})
 
 		# Prendre ses propres entrees
-		for f in self.keys ():
+		for f in self.personal_keys ():
 			ret [f] = self [f]
 
 		# et ajouter celles qu'on n'a pas
@@ -235,19 +233,20 @@ class Entry:
 			if not self.has_key (f):
 				ret [f] = other [f]
 
+		ret.crossref = self.crossref
 		return ret
 
 
 	def __repr__ (self):
-		return "<entry `" + self.name + "'>"
+		return "<entry `" + self.key.key + "'>"
 
 
 	def __str__ (self):
-		""" Nice standard entry  """
+		''' Nice standard entry  '''
 		tp = self.type.name
 		fields = self.type.fields
 			
-		text = '%s [%s]\n' % (tp, self.name)
+		text = '%s [%s]\n' % (tp, self.key.key)
 		text = text + ('-' * 70) + '\n'
 		
 		dico = self.keys ()
@@ -283,14 +282,14 @@ SortByKey  = 0
 SortByType = 1
 
 class DataBase:
-	"""
+	'''
 	This class represents a full bibliographic database.
 	It also looks like a dictionnary, each key being an instance
 	of class Key.
 
 	The foreach() method should provide an efficient way of
 	looping over all the elements, if one exists. 
-	"""
+	'''
 
 	# a default database provides no editing facilities
 	# (as it cannot be saved)
@@ -311,7 +310,7 @@ class DataBase:
 		return
 	
 	def has_property (self, prop):
-		""" indicates if the database has a given property """
+		''' indicates if the database has a given property '''
 		
 		if self.properties.has_key (prop):
 			return self.properties [prop]
@@ -319,7 +318,7 @@ class DataBase:
 		return 0
 	
 	def new_entry (self):
-		""" returns a newly created entry """
+		''' returns a newly created entry '''
 
 		name = None
 		key  = None
@@ -335,34 +334,34 @@ class DataBase:
 		type = Config.get ("base/defaulttype").data
 
 		# return the new entry
-		return Entry (key, name, type, {})
+		return Entry (key, type)
 
 
 	def keys (self):
-		""" Returns a list of all the keys available for the database """
+		''' Returns a list of all the keys available for the database '''
 		return self.__dict.keys ()
 
 	def has_key (self, key):
-		""" Tests for a given key """
+		''' Tests for a given key '''
 		return self.__dict.has_key (key)
 
 	def __getitem__ (self, key):
-		""" Returns the Entry object associated with the key """
+		''' Returns the Entry object associated with the key '''
 		return self.__dict [key]
 
 	def __setitem__ (self, key, value):
-		""" Sets a key Entry """
+		''' Sets a key Entry '''
 		
 		self.__dict [key] = value
 		return
 
 	def __delitem__ (self, key):
-		""" Removes an Entry from the database, by its key """
+		''' Removes an Entry from the database, by its key '''
 		del self.__dict [key]
 		return
 	
 	def __len__ (self):
-		""" Number of entries in the database """
+		''' Number of entries in the database '''
 		return len (self.keys ())
 
 	def __repr__ (self):
@@ -371,8 +370,8 @@ class DataBase:
 		
 
 	def where (self, test):
-		""" Returns a subset of the entries according to a
-		criterion """
+		''' Returns a subset of the entries according to a
+		criterion '''
 		keys = []
 		for e in self.keys ():
 			if test.match (self [e]):
@@ -387,14 +386,14 @@ class DataBase:
 		return refs
 	
 	def foreach (self, function, args = None):
-		""" Run function on every entry. """
+		''' Run function on every entry. '''
 		
 		for e in self.keys ():
 			function (self [e], args)
 		return
 
 	def update (self):
-		""" Updates the Entries stored in the database """
+		''' Updates the Entries stored in the database '''
 		
 		raise IOError, "no update method defined"
 		return
@@ -402,8 +401,8 @@ class DataBase:
 
 	def sort (self, sortkey = SortByKey):
 
-		""" sort entries according to a given key.  If the
-		sortkey is None, sort according to the entry key """
+		''' sort entries according to a given key.  If the
+		sortkey is None, sort according to the entry key '''
 		
 		# collect key values
 		dict = {}
@@ -447,7 +446,7 @@ class DataBase:
 
 # ----- A class that holds references from several databases -----
 
-Pyblio.Help.register ('references', """
+Pyblio.Help.register ('references', '''
 
 References are generic holders of subsets or complete databases. One
 can apply several method on a reference :
@@ -464,11 +463,16 @@ can apply several method on a reference :
  - ref.base_foreach (base) : like `foreach' but only on a given database
 
 In addition, references can be merged with `+'.
-""")
+''')
 
 
 class Reference (DataBase):
 
+	''' This class is a specialization of DataBase, whose purpose
+	is to store entries from different sources, and to keep the
+	order of these entries. Therefore it is often used to store
+	the results of a sort or search operation. '''
+	
 	__count = 0
 	id = 'Reference'
 
@@ -482,9 +486,9 @@ class Reference (DataBase):
 
 		return
 	
-
+	
 	def add (self, base, liste = None):
-		""" Ajouter des references liees a une base """
+		''' Add a list of Keys corresponding to a given database '''
 
 		if base.id == 'Reference':
 			for b in base.bases ():
@@ -501,24 +505,29 @@ class Reference (DataBase):
 			self.__refs.append (liste)
 		return
 
+	def remove (self, key):
+		''' Removes a Key from the Reference (no impact on the
+		underlying database '''
 
-	def __repr__ (self):
-		""" Representation of the database """
-		return "Reference (<...%d entries...>)" % len (self.keys ())
+		self.__refs.remove (key)
+		return
 
+	
 	def bases (self):
-		""" Returns the databases available in the Reference
-		object """
+		''' Returns the databases available in the Reference
+		object '''
 		
 		return self.__bases.values ()
 	
+
 	def base (self, entry):
-		""" Returns the database the entry actually comes from """
+		''' Returns the database an entry actually comes from '''
 		return self.__bases [entry.key.base]
+
 	
 	def refs (self, base):
-		""" Returns the references available in a given
-		database """
+		''' Returns the references available in a given
+		database '''
 		
 		if self.__bases.has_key (base.key):
 			return filter (lambda x, base = base:
@@ -527,38 +536,95 @@ class Reference (DataBase):
 		
 		return None
 
+
 	def base_foreach (self, base, function, arg = None):
-		""" Foreach entry in a base """
+		''' Foreach entry in a given base '''
 		
 		for k in self.refs (base):
 			entry = base [k]
 			function (entry, arg)
 		return
-	
-	def foreach (self, function, arg = None):
-		"Foreach entry"
 
+	
+	def __add__ (self, other):
+		''' Merges two References to create a third one '''
+		
+		r = Reference ()
+
+		for b in self.bases ():
+			r.add (b, self.refs (b))
+
+		for b in other.bases ():
+			r.add (b, other.refs (b))
+
+		return r
+
+
+	def foreach (self, function, arg = None):
+		''' Foreach entry in all the databases '''
+		
 		for k in self.keys ():
 			function (self [k], arg)
 		return
 		
 
 	def __len__ (self):
+		''' Number of entries in the Reference '''
+		
 		return len (self.keys ())
 
 
 	def keys (self):
-		return self.__refs
-					  
+		''' Returns the list of the keys in the Reference '''
+		
+		# Only returns the really existing keys
+		ret = []
+		bad = []
+		# separate the already existing keys from those who
+		# vanished
+		for k in self.__refs:
+			if self.__bases [k.base].has_key (k):
+				ret.append (k)
+			else:
+				bad.append (k)
+
+		# remove the bad keys
+		for k in bad:
+			self.__refs.remove (k)
+			
+		return ret
+
+	
 	def has_key (self, key):
-		return self.__refs.count (key)
+		''' Tests if a Key is in the Reference '''
+		
+		# Do we know this key ?
+		if not self.__refs.count (key):
+			return 0
+		# If yes, does it still exist ?
+		if self.__bases [key.base] [key]:
+			return 1
+		# So, remove it for the next time !
+		self.__refs.remove (key)
+		return 0
+
 	
 	def __getitem__ (self, key):
+		''' Returns an Entry given its Key '''
 		return self.__bases [key.base] [key]
 
-	def __delitem__ (self, key):
-		del self.__bases [key.base] [key]
 
+	def __delitem__ (self, key):
+		''' Removes an Entry (both in the Reference and in the
+		real database) '''
+		
+		# delete from the target database
+		del self.__bases [key.base] [key]
+		# delete from our list
+		self.__refs.remove (key)
+		return
+
+	
 	def __setitem__ (self, key, value):
 		self.__bases [key.base] [key] = value
 
@@ -571,24 +637,14 @@ class Reference (DataBase):
 			
 			self.__refs.append (key)
 		return
+
 	
-	def __add__ (self, other):
-
-		r = Reference ()
-
-		for b in self.bases ():
-			r.add (b, self.refs (b))
-
-		for b in other.bases ():
-			r.add (b, other.refs (b))
-
-		return r
-
 	def new_entry (self):
 		if self.has_property ('add'):
 			return self.bases () [0].new_entry ()
 
 		return DataBase.new_entry (self)
+
 		
 	def update (self):
 		# if we have any edition property
@@ -600,7 +656,7 @@ class Reference (DataBase):
 			return
 		
 		# else, raise an error
-		raise IOError, "can't update a database of type Reference"
+		raise IOError, "can't update a database of type Reference ()"
 	
 
 	def where (self, test):
@@ -615,3 +671,8 @@ class Reference (DataBase):
 		r.properties = self.properties
 		return r
 
+
+	def __repr__ (self):
+		''' Representation of the database '''
+		
+		return "Reference (<...%d entries...>)" % len (self.keys ())
