@@ -17,11 +17,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Config.py,v 1.2 1999/08/27 12:37:19 gobry Exp $
+# $Id: Config.py,v 1.1.1.1 1999/11/22 13:29:30 fredgo Exp $
 
 import string, os
 
-""" System for Configuration handling """
+''' System for Configuration handling '''
 
 class ConfigItem:
 
