@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Fields.py,v 1.14 1999/09/30 15:21:04 gobry Exp $
+# $Id: Fields.py,v 1.1.1.1 1999/11/22 13:29:30 fredgo Exp $
 
 import string, types, re, string, recode
 
@@ -26,8 +26,8 @@ year_match = re.compile ('(\d\d\d\d)')
 formatter_cache = {}
 
 def get_formatter (format):
-    """ This function is used to get a recode formatter in an
-    efficient way """
+    ''' This function is used to get a recode formatter in an
+    efficient way '''
     
     format = string.lower (format)
     
@@ -41,8 +41,8 @@ def get_formatter (format):
 
 
 class Access:
-    """ virtual class used to check if instance attributes have been
-    modified """
+    ''' virtual class used to check if instance attributes have been
+    modified '''
     
     def __init__ (self):
         self.clean ()
@@ -69,10 +69,10 @@ class Access:
 
 
 class Author (Access):
-    """ Fine description of an author """
+    ''' Fine description of an author '''
     
     def __init__ (self, copy = None, strict = 0):
-        """ Initialize an author from a string or an other Author """
+        ''' Initialize an author from a string or an other Author '''
 
         if type (copy) is types.StringType:
             # manually split the author into subfields.
@@ -96,7 +96,7 @@ class Author (Access):
                     
                     self.first = string.join (words [:i], ' ')
                     self.last  = string.join (words [i:], ' ')
-                
+                    
             elif len (blocs) == 2:
                 self.last  = string.strip (blocs [0])
                 self.first = string.strip (blocs [1])
@@ -114,6 +114,7 @@ class Author (Access):
             if self.last == '':    self.last    = None
             if self.first == '':   self.first   = None
             if self.lineage == '': self.lineage = None
+                        
         else:
             if copy:
                 def clean_entry (f):
@@ -142,7 +143,7 @@ class Author (Access):
 
 
     def format (self, fmt):
-        """ Returns the fields in a given format """
+        ''' Returns the fields in a given format '''
         
         ft = get_formatter (fmt)
             
@@ -151,7 +152,7 @@ class Author (Access):
 
     
     def __str__ (self):
-        """ Returns textual representation """
+        ''' Returns textual representation '''
 
         changed = self.modified ()
         if changed or not self.text:
@@ -172,12 +173,12 @@ class Author (Access):
 
 
     def match (self, regex):
-        """ """
+        ''' '''
         return regex.search (str (self))
 
 
     def initials (self, format = None):
-        """ Extract initials from a first name """
+        ''' Extract initials from a first name '''
 
         total = []
 
@@ -199,7 +200,7 @@ class Author (Access):
         return text
 
     def __cmp__ (self, other):
-        """ field comparison """
+        ''' field comparison '''
         
         r = cmp (self.last, other.last)
         if r != 0: return r
@@ -217,7 +218,7 @@ class Author (Access):
 
 
 class AuthorGroup (Access):
-    """ A group of Authors """
+    ''' A group of Authors '''
 
     def __init__ (self):
         self.authors = []
@@ -280,7 +281,7 @@ class AuthorGroup (Access):
 RangeError = "RangeError"
 
 class Date (Access):
-    """ Fine description of a date """
+    ''' Fine description of a date '''
 
     def __init__ (self, arg = (None, None, None)):
 
@@ -314,7 +315,7 @@ class Date (Access):
         self.text = None
         Access.__init__ (self)
         return
-        
+
     def __cmp__ (self, other):
 
         # No date is no date !
@@ -335,7 +336,7 @@ class Date (Access):
         return (self.day or other.day) - (other.day or self.day)
 
     def __str__ (self):
-        """ Returns textual representation """
+        ''' Returns textual representation '''
         changed = self.modified ()
 
         if changed or not self.text:
@@ -351,7 +352,7 @@ class Date (Access):
         return self.text
 
     def format (self, fmt):
-        """ Returns the fields in a given format """
+        ''' Returns the fields in a given format '''
         ft = get_formatter (fmt)
 
         if self.year:
@@ -374,14 +375,14 @@ class Date (Access):
 
 
     def match (self, regex):
-        """ """
+        ''' '''
         return regex.search (str (self))
         
 
 class Text (Access):
-    """
+    '''
     This class holds all the other fields (not an Author or a Date)
-    """
+    '''
     
     def __init__ (self, text):
         self.text = text
@@ -399,7 +400,7 @@ class Text (Access):
 
 
     def match (self, regex):
-        """   """
+        '''   '''
         return regex.search (self.text)
 
 
@@ -408,7 +409,7 @@ class Text (Access):
 
 
     def format (self, fmt):
-        """ Returns the fields in a given format """
+        ''' Returns the fields in a given format '''
         ft = get_formatter (fmt)
 
         return ft (self.text)
