@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Refer.py,v 1.6 1999/09/24 07:21:22 gobry Exp $
+# $Id: Refer.py,v 1.1.1.1 1999/11/22 13:29:31 fredgo Exp $
 
 # Extension module for Refer files
 
@@ -118,7 +118,7 @@ class ReferBase (Base.DataBase):
                             continue
                         fields [f] = Fields.Text (fields [f] [0])
                         
-                self [real] = Base.Entry (real, name, entry, fields)
+                self [real] = Base.Entry (real, entry, fields)
                 
                 # start a new entry
                 fields = {}
