@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Entry.py,v 1.11 1999/09/27 15:56:24 gobry Exp $
+# $Id: Entry.py,v 1.1.1.1 1999/11/22 13:29:31 fredgo Exp $
 
 from Pyblio.Base import *
 import string, re
@@ -25,17 +25,21 @@ from gnome.ui import *
 from gtk import *
 import GTK
 
+import gettext
+_ = gettext.gettext
+
 from Pyblio import Fields, Config, Base, Types
 
 from Pyblio.GnomeUI import FieldsInfo, Utils
 
 
-regular_field = re.compile ("^\w+$")
-regular_id    = re.compile ("^\w[\d\w:_-]+$")
+regular_field = re.compile ('^\w+$')
+regular_id    = re.compile ('^\w[\d\w:_-]+$')
 
 
 class NativeEditor (GtkDialog):
-    """ Implements a dialog that display a simple edition box for native entry """
+    ''' Implements a dialog that display a simple edition box for
+    native entry '''
     
     def __init__ (self, entry, text = None):
         
@@ -48,17 +52,25 @@ class NativeEditor (GtkDialog):
         
         GtkDialog.__init__ (self)
 
-        self.set_title ("Native edition of field `%s'" % entry.field)
+        self.set_title (_("Native edition of field `%s'") % entry.field)
         self.set_modal (TRUE)
         self.set_usize (400, 200)
         
-        self.connect("delete_event", self.close)
+        self.connect('delete_event', self.close)
 
         apply_b = GnomeStockButton (STOCK_BUTTON_APPLY)
-        apply_b.connect ("clicked", self.apply)
+        apply_b.connect ('clicked', self.apply)
 
         close_b = GnomeStockButton (STOCK_BUTTON_CANCEL)
-        close_b.connect ("clicked", self.close)
+        close_b.connect ('clicked', self.close)
+
+        # Use Escape to abort, Ctrl-Return to accept
+        acc = GtkAccelGroup ()
+        self.add_accel_group (acc)
+
+        close_b.add_accelerator ('clicked', acc, GDK.Escape, 0, 0)
+        apply_b.add_accelerator ('clicked', acc, GDK.Return,
+                                 GDK.CONTROL_MASK, 0)
 
         self.action_area.add (apply_b)
         self.action_area.add (close_b)
@@ -68,6 +80,9 @@ class NativeEditor (GtkDialog):
         
         self.editor = GtkText ()
         self.editor.set_editable (TRUE)
+
+        self.editor.connect ('key_press_event', self.key_handler,
+                             apply_b)
         
         scrolled = GtkScrolledWindow ()
         scrolled.set_policy (POLICY_AUTOMATIC, POLICY_AUTOMATIC)
@@ -117,6 +132,13 @@ class NativeEditor (GtkDialog):
         if self.running: mainquit ()
         return
 
+    def key_handler (self, widget, ev, button):
+        if ev.keyval == GDK.Return and \
+           ev.state  == GDK.CONTROL_MASK:
+            widget.emit_stop_by_name ('key_press_event')
+            button.emit ('clicked')
+        return 1
+    
     def run_and_close (self):
         self.show ()
         self.running = 1
@@ -130,8 +152,8 @@ class BasicEditor (GtkHBox):
                   entry, field,
                   value = None, loss = 0, has_native = 1):
 
-        """ Edit a given field in a given Entry. It is possible to specify
-        the current aspect of the edition box """
+        ''' Edit a given field in a given Entry. It is possible to specify
+        the current aspect of the edition box '''
         
         GtkHBox.__init__ (self, FALSE, 5)
 
@@ -166,10 +188,10 @@ class BasicEditor (GtkHBox):
             
             self.button = GtkButton ()
             self.button.add (icon)
-            self.button.connect ("clicked", self.edit_native)
+            self.button.connect ('clicked', self.edit_native)
         
             Utils.tooltips.set_tip (self.button,
-                                    "Edit the field in its Native format")
+                                    _("Edit the field in its Native format"))
         
             self.pack_end (self.button, FALSE, FALSE)
             
@@ -178,8 +200,8 @@ class BasicEditor (GtkHBox):
         return
 
     def modified_cb (self, * arg):
-        """ called when the textual entry is modified. This discards the
-        native edition """
+        ''' called when the textual entry is modified. This discards the
+        native edition '''
         
         if not self.__in_fill:
             self.modified = 0
@@ -187,7 +209,7 @@ class BasicEditor (GtkHBox):
         return
     
     def set_editable (self, val):
-        """ make the entry field editable or not """
+        ''' make the entry field editable or not '''
         
         self.editor.set_editable (val)
         self.button.set_sensitive (val)
@@ -211,7 +233,7 @@ class BasicEditor (GtkHBox):
     
     
     def fill (self, text = None):
-        """ Fill the field with a given Field value """
+        ''' Fill the field with a given Field value '''
         
         self.__in_fill = 1
 
@@ -228,7 +250,7 @@ class BasicEditor (GtkHBox):
 
     
     def update (self):
-        """ Update the real entry according to the modifications """
+        ''' Update the real entry according to the modifications '''
 
         # entry not editable -> nothing to update
         if not self.editable: return 0
@@ -239,7 +261,7 @@ class BasicEditor (GtkHBox):
         if self.modified:
             self.entry.set_native (self.field, self.native)
             return 1
-        
+
         if (new is None and self.value is not None) or \
            (new is not None and self.value is None) or \
            new != self.value:
@@ -255,8 +277,21 @@ class BasicEditor (GtkHBox):
         return 0
 
 
+    def key_handler (self, widget, ev, button):
+        if ev.keyval == GDK.Return and \
+           ev.state  == GDK.CONTROL_MASK:
+            widget.emit_stop_by_name ('key_press_event')
+            button [0].emit ('clicked')
+            return 1
+        if ev.keyval == GDK.Tab and \
+           ev.state  == GDK.CONTROL_MASK:
+            widget.emit_stop_by_name ('key_press_event')
+            button [1].emit ('clicked')
+        return 1
+
+
     def get (self):
-        """ Create a Field from the edition box """
+        ''' Create a Field from the edition box '''
         
         text = string.strip (self.editor.get_text ())
         
@@ -267,7 +302,9 @@ class BasicEditor (GtkHBox):
     
 class TextEditor (BasicEditor):
     
-    def __init__ (self, entry, field, value = None, loss = 0, has_native = 1):
+    def __init__ (self, entry, field, apply_b,
+                  value = None, loss = 0, has_native = 1):
+        
         BasicEditor.__init__ (self, entry, field, value, loss, has_native)
         
         scrolled = GtkScrolledWindow ()
@@ -277,14 +314,18 @@ class TextEditor (BasicEditor):
         self.editor.set_editable (TRUE)
         self.editor.set_usize (300,100)
         self.editor.set_word_wrap (1)
-        self.editor.connect ("changed", self.modified_cb)
+        self.editor.connect ('changed', self.modified_cb)
         
+        self.editor.connect ('key_press_event', self.key_handler,
+                             apply_b)
+
         scrolled.add (self.editor)
         self.pack_start (scrolled, TRUE, TRUE)
         
         self.fill (value)
         return
 
+    
     def fill (self, text = None):
         if text is None:
             text = self.value
@@ -307,18 +348,23 @@ class TextEditor (BasicEditor):
 
 class AuthorEditor (BasicEditor):
     
-    def __init__ (self, entry, field, value = None, loss = 0, has_native = 1):
+    def __init__ (self, entry, field, apply_b,
+                  value = None, loss = 0, has_native = 1):
+        
         BasicEditor.__init__ (self, entry, field, value, loss, has_native)
 
         scrolled = GtkScrolledWindow ()
         scrolled.set_policy (POLICY_AUTOMATIC, POLICY_AUTOMATIC)
         
         self.editor = GtkText ()
-        self.editor.connect ("changed", self.modified_cb)
+        self.editor.connect ('changed', self.modified_cb)
         self.editor.set_editable (TRUE) 
         self.editor.set_word_wrap (1)
         self.editor.set_usize (300,100)
         
+        self.editor.connect ('key_press_event', self.key_handler,
+                             apply_b)
+
         scrolled.add (self.editor)
         self.pack_start (scrolled, TRUE, TRUE)
         self.fill (value)
@@ -344,7 +390,7 @@ class AuthorEditor (BasicEditor):
         self.editor.delete_text (0, -1)
         
         if text is not None:
-            self.editor.insert_defaults (join (map (str_auth, text), "\n"))
+            self.editor.insert_defaults (join (map (str_auth, text), '\n'))
             
         self.editor.thaw ()
         return
@@ -361,14 +407,19 @@ class AuthorEditor (BasicEditor):
 
         if len (autg) == 0: return None
         return autg
+
     
 class FieldEditor (BasicEditor):
     
-    def __init__ (self, entry, field, value = None, loss = 0, has_native = 1):
+    def __init__ (self, entry, field, apply_b,
+                  value = None, loss = 0, has_native = 1):
+        
         BasicEditor.__init__ (self, entry, field, value, loss, has_native)
         
         self.editor = GtkEntry ()
-        self.editor.connect ("changed", self.modified_cb)
+        self.editor.connect ('key_press_event', self.key_handler,
+                             apply_b)
+        self.editor.connect ('changed', self.modified_cb)
         self.editor.set_editable (TRUE)
         self.pack_start (self.editor, TRUE, TRUE)
         self.fill (value)
@@ -378,11 +429,15 @@ class FieldEditor (BasicEditor):
 
 class DateEditor (BasicEditor):
     
-    def __init__ (self, entry, field, value = None, loss = 0, has_native = 1):
+    def __init__ (self, entry, field, apply_b,
+                  value = None, loss = 0, has_native = 1):
+        
         BasicEditor.__init__ (self, entry, field, value, loss, has_native)
         
         self.editor = GtkEntry ()
-        self.editor.connect ("changed", self.modified_cb)
+        self.editor.connect ('key_press_event', self.key_handler,
+                             apply_b)
+        self.editor.connect ('changed', self.modified_cb)
         self.editor.set_editable (TRUE)
         self.pack_start (self.editor, TRUE, TRUE)
         self.fill (value)
@@ -469,16 +524,17 @@ class FieldGroup:
     
     
 class Entry (GtkVBox):
-    """ Entry displayer """
+    ''' Entry displayer '''
     
-    def __init__ (self, entry, properties, acc, database):
+    def __init__ (self, entry, apply_b, properties, database):
         GtkVBox.__init__ (self, FALSE)
 
         self.entry       = entry
         self.properties  = properties
         self.changed     = 0
-        self.accelerator = acc
         self.database    = database
+        self.apply_b     = apply_b
+        self.extra_keys  = []
         
         ent = entry.type
 
@@ -493,10 +549,12 @@ class Entry (GtkVBox):
         table.attach (GtkLabel ('Identifier'), 1, 2, 0, 1)
 
         self.name = GtkEntry ()
-
+        self.name.show ()
+        
         if self.has_property ('change_type'):
             self.type = GtkOptionMenu ()
-            available = map (lambda x: x.name, Config.get ("base/entries").data.values ())
+            available = map (lambda x: x.name,
+                             Config.get ('base/entries').data.values ())
             available.sort ()
             
             menu = GtkMenu ()
@@ -511,13 +569,11 @@ class Entry (GtkVBox):
             self.type.set_text (ent.name)
             self.type.set_editable (FALSE)
 
-        
-        self.name.set_text (entry.name)
+        self.name.set_text (entry.key.key)
 
         if not self.has_property ('change_id'):
             self.name.set_editable (FALSE)
 
-
         table.attach (self.type, 0, 1, 1, 2)
         table.attach (self.name, 1, 2, 1, 2)
             
@@ -528,21 +584,22 @@ class Entry (GtkVBox):
             box = GtkHBox (FALSE, 5)
             box.set_border_width (5)
 
-            box.pack_start (GtkLabel ('Cross-Reference:'), fill=FALSE, expand = FALSE)
+            box.pack_start (GtkLabel ('Cross-Reference:'), fill = FALSE,
+                            expand = FALSE)
             
             self.crossref = GtkEntry ()
             self.crossref.set_editable (FALSE)
             Utils.tooltips.set_tip (self.crossref,
-                                    "Drag an Entry to define a Cross-Reference")
+                                    _("Drag an Entry to define a Cross-Reference"))
             
             box.pack_start (self.crossref)
 
             button = GtkButton ()
             button.add (GnomeStock (STOCK_BUTTON_CANCEL))
-            button.connect ("clicked", self.remove_crossref)
+            button.connect ('clicked', self.remove_crossref)
             
             Utils.tooltips.set_tip (button,
-                                    "Remove the current Cross-Reference")
+                                    _("Remove the current Cross-Reference"))
             
             box.pack_start (button, fill = FALSE, expand = FALSE)
             
@@ -554,8 +611,10 @@ class Entry (GtkVBox):
 
             targets = [ ('application/x-pybkey', 0, 1) ]
             
-            self.crossref.connect ('drag_data_received', self.dnd_drag_data_received)
-            self.crossref.drag_dest_set(DEST_DEFAULT_ALL, targets, GDK.ACTION_COPY)
+            self.crossref.connect ('drag_data_received',
+                                   self.dnd_drag_data_received)
+            self.crossref.drag_dest_set(DEST_DEFAULT_ALL, targets,
+                                        GDK.ACTION_COPY)
 
             box.show_all ()
             
@@ -563,24 +622,15 @@ class Entry (GtkVBox):
             # extra field addition
             hbox   = GtkHBox (FALSE, 5)
             hbox.set_border_width (5)
-            select = GnomeEntry ("extra-entry")
+            select = GnomeEntry ('extra-entry')
             hbox.pack_start (select)
-            add_button = GtkButton ("Add Extra Field")
+            add_button = GtkButton (_("Add Extra Field"))
             hbox.pack_start (add_button)
             self.pack_start (hbox, fill=FALSE, expand=FALSE)
 
-            add_button.connect ("clicked", self.extra_field, select)
+            add_button.connect ('clicked', self.extra_field, select)
             hbox.show_all ()
             
-        # an invisible button
-        button = GtkButton ()
-        button.hide ()
-        button.set_usize (0,0)
-        self.pack_start (button)
-        button.connect ("clicked", self.next_entry)
-        button.add_accelerator ("clicked", self.accelerator,
-                                GDK.Escape, 0, 0)
-
         # fill in the data for the notebook
         self.current_data = {}
         
@@ -608,7 +658,8 @@ class Entry (GtkVBox):
         try:
             crossref = self.database [Base.Key (self.entry.key.base, name)]
         except KeyError:
-            d = GnomeErrorDialog ("Cross-Reference `%s' is unexistant in the database" % cr)
+            d = GnomeErrorDialog \
+                (_("Cross-Reference `%s' is unexistant in the database") % cr)
             d.run_and_close ()
             return
         
@@ -649,7 +700,8 @@ class Entry (GtkVBox):
         try:
             crossref = self.database [Base.Key (self.entry.key.base, name)]
         except KeyError:
-            d = GnomeErrorDialog ("Cross-Reference `%s' is unexistant in the database" % cr)
+            d = GnomeErrorDialog \
+                (_("Cross-Reference `%s' is unexistant in the database") % cr)
             d.run_and_close ()
             return
 
@@ -659,9 +711,9 @@ class Entry (GtkVBox):
                 value, loss, edit = self.current_data [k]
 
             if not edit:
-                self.current_data [k] = ["", 0, 1]
+                self.current_data [k] = ['', 0, 1]
 
-        self.crossref.set_text ("")
+        self.crossref.set_text ('')
 
         # Refresh the whole stuff
         self.remove (self.notebook)
@@ -669,7 +721,7 @@ class Entry (GtkVBox):
         return
     
     def has_property (self, prop):
-        """ indicates if the database has a given property """
+        ''' indicates if the database has a given property '''
 		
         if self.properties.has_key (prop):
             return self.properties [prop]
@@ -699,19 +751,24 @@ class Entry (GtkVBox):
                 value, loss, perso = None, 0, 1
 
             if type == FieldsInfo.WidgetText: 
-                tmp = TextEditor (entry, field, value, loss, native)
+                tmp = TextEditor (entry, field, self.apply_b,
+                                  value, loss, native)
 
             elif type == FieldsInfo.WidgetEntry:
-                tmp = FieldEditor (entry, field, value, loss, native)
+                tmp = FieldEditor (entry, field, self.apply_b,
+                                   value, loss, native)
 
             elif type == FieldsInfo.WidgetAuthor:
-                tmp = AuthorEditor (entry, field, value, loss, native)
+                tmp = AuthorEditor (entry, field, self.apply_b,
+                                    value, loss, native)
 
             elif type == FieldsInfo.WidgetDate:
-                tmp = DateEditor (entry, field, value, loss, native)
+                tmp = DateEditor (entry, field, self.apply_b,
+                                  value, loss, native)
 
             else:
-                tmp = TextEditor (entry, field, value, loss, native)
+                tmp = TextEditor (entry, field, self.apply_b,
+                                  value, loss, native)
 
             tmp.show ()
 
@@ -721,7 +778,7 @@ class Entry (GtkVBox):
                 
             return tmp
         
-        dico = self.entry.keys ()
+        dico = self.entry.keys () + self.extra_keys
 
         for f in ent.mandatory:
             lc = string.lower (f.name)
@@ -737,22 +794,19 @@ class Entry (GtkVBox):
             self.extra [lc] = get_field (self.entry, lc)
 
         table = self.mandatory.as_table ()
-        self.notebook.append_page (table, GtkLabel ("Mandatory"))
+        self.notebook.append_page (table, GtkLabel (_("Mandatory")))
 
         table = self.optional.as_table ()
-        self.notebook.append_page (table, GtkLabel ("Optional"))
+        self.notebook.append_page (table, GtkLabel (_("Optional")))
 
         table = self.extra.as_table ()
-        self.notebook.append_page (table, GtkLabel ("Extra"))
+        self.notebook.append_page (table, GtkLabel (_("Extra")))
 
         self.notebook.show_all ()
         self.pack_start (self.notebook)
         return
 
-    def type_changed (self, menu, type):
-        type = Types.getentry (type)
-        self.entry.type = type
-
+    def store_tmp_data (self):
         # get the changed values
         for k in self.mandatory.keys ():
             value       = self.mandatory [k].get ()
@@ -777,7 +831,15 @@ class Entry (GtkVBox):
                 self.current_data [k] [0] = value
             else:
                 self.current_data [k] = [value, 0, 1]
-                
+
+        return
+    
+    def type_changed (self, menu, type):
+        type = Types.getentry (type)
+        self.entry.type = type
+
+        self.store_tmp_data ()
+        
         # Refresh the whole stuff
         self.remove (self.notebook)
         self.create_notebook (type)
@@ -789,22 +851,27 @@ class Entry (GtkVBox):
         text = string.lower (string.strip (widget.gtk_entry ().get_text ()))
         
         if not regular_field.search (text):
-            d = GnomeErrorDialog ("Invalid field name `%s'" % text)
+            d = GnomeErrorDialog (_("Invalid field name `%s'") % text)
             d.run_and_close ()
             return
 
         if self.entry.has_key (text):
-            d = GnomeErrorDialog ("Key `%s' already defined" % text)
+            d = GnomeErrorDialog (_("Key `%s' already defined") % text)
             d.run_and_close ()
             return
             
-        self.entry [text] = 'new entry'
-        
+        self.extra_keys.append (text)
+
+        self.store_tmp_data ()
+
         # Refresh the whole stuff
         self.remove (self.notebook)
         self.create_notebook (self.entry.type)
         self.changed = 1
         self.notebook.set_page (2)
+
+        box = self.notebook.get_nth_page (2)
+        box.focus (GTK.DIR_DOWN)
         return
     
 class EntryDialog (GtkDialog):
@@ -816,30 +883,53 @@ class EntryDialog (GtkDialog):
         self.set_policy (TRUE, TRUE, TRUE)
 
         self.set_title ('Edit')
-        self.connect("delete_event", self.close)
+        self.connect('delete_event', self.close)
 
         self.database = database
         self.callback = callback
         self.user     = user
-
-        acc = GtkAccelGroup ()
-        self.add_accel_group (acc)
-
-        self.entry = Entry (entry, database.properties, acc, database)
         
         apply_b = GnomeStockButton (STOCK_BUTTON_APPLY)
-        apply_b.connect ("clicked", self.apply)
+        apply_b.connect ('clicked', self.apply)
         apply_b.show ()
         
         close_b = GnomeStockButton (STOCK_BUTTON_CANCEL)
-        close_b.connect ("clicked", self.close)
+        close_b.connect ('clicked', self.close)
         close_b.show ()
+
+        next_b = GtkButton ()
+        self.vbox.pack_start (next_b)
+        next_b.connect ('clicked', self.next_item)
         
+        self.entry = Entry (entry, (apply_b, next_b),
+                            database.properties, database)
+
+        # Use Escape to abort, Ctrl-Return to accept
+        acc = GtkAccelGroup ()
+        self.add_accel_group (acc)
+
+        close_b.add_accelerator ('clicked', acc, GDK.Escape, 0, 0)
+        apply_b.add_accelerator ('clicked', acc, GDK.Return, GDK.CONTROL_MASK,
+                                 0)
+
         self.action_area.add (apply_b)
         self.action_area.add (close_b)
 
         self.vbox.pack_start (self.entry)
         self.entry.show ()
+        if self.entry.has_property ('change_id'):
+            self.entry.name.grab_focus ()
+        return
+
+    def next_entry (self, widget, key, page):
+        n = self.entry.notebook
+        box = n.get_nth_page (arg)
+        
+        box.focus (GTK.DIR_DOWN)
+        return
+
+    def next_item (self, *arg):
+        self.entry.focus (GTK.DIR_DOWN)
         return
 
     def apply (self, widget):
@@ -854,19 +944,28 @@ class EntryDialog (GtkDialog):
         id = string.strip (self.entry.name.get_text ())
         
         if not regular_id.search (id):
-            d = GnomeErrorDialog ("Invalid identifier `%s'" % id)
+            d = GnomeErrorDialog (_("Invalid identifier `%s'") % id)
             d.run_and_close ()
             return
             
-        elif id != self.entry.entry.name:
+        elif id != self.entry.entry.key.key:
+
+            key = Base.Key (self.entry.entry.key.base, id)
             
             # check unicity
-            if not self.database.has_key (Base.Key (self.entry.entry.key.base, id)):
-                # only change the name, the key will follow at the next save.
-                self.entry.entry.name = id
+            if not self.database.has_key (key):
+                # set the new key and remove the previous one...
+                
+                if self.database.has_key (self.entry.entry.key):
+                    # if this entry is not brand new...
+                    # remove it !
+                    del self.database [self.entry.entry.key]
+                    
+                self.entry.entry.key = key
+                self.database [key] = self.entry.entry
                 changed = 1
             else:
-                d = GnomeErrorDialog ("Identifier `%s' already exists" % id)
+                d = GnomeErrorDialog (_("Identifier `%s' already exists") % id)
                 d.run_and_close ()
                 return
 
@@ -886,9 +985,13 @@ class EntryDialog (GtkDialog):
             else:
                 # add a new crossref
                 try:
-                    self.entry.entry.crossref = self.database [Base.Key (self.entry.entry.key.base, cr)]
+                    self.entry.entry.crossref = self.database \
+                                                [Base.Key
+                                                 (self.entry.entry.key.base,
+                                                  cr)]
                 except KeyError:
-                    d = GnomeErrorDialog ("Cross-Reference `%s' is unexistant in the database" % cr)
+                    d = GnomeErrorDialog (
+                        _("Cross-Reference `%s' is unexistant in the database") % cr)
                     d.run_and_close ()
                     return
                 
