@@ -17,10 +17,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Search.py,v 1.7 1999/08/31 09:49:43 gobry Exp $
+# $Id: Search.py,v 1.1.1.1 1999/11/22 13:29:31 fredgo Exp $
 
 from gnome.ui import *
 from gtk import *
+import GTK
 
 import string, re, sys, traceback, copy
 
@@ -31,12 +32,15 @@ from Pyblio.GnomeUI import Utils
 import Pyblio.GnomeUI.Database
 import Pyblio.TextUI
 
+import gettext
+_ = gettext.gettext
+
 
 def popup_add (menu, item, action = None, argument = None):
-    """ Helper to add a new menu entry """
+    ''' Helper to add a new menu entry '''
     tmp = GtkMenuItem (item)
     if action:
-        tmp.connect ("activate", action, argument)
+        tmp.connect ('activate', action, argument)
     tmp.show ()
     menu.append (tmp)
     
@@ -95,7 +99,6 @@ class ItemStorage (GtkTreeItem):
             self.children.remove (child)
 
         self.tree = None
-        #GtkTreeItem.remove_subtree (self)
         return
     
     def search (self, name):
@@ -109,26 +112,31 @@ class ItemStorage (GtkTreeItem):
         return None
     
 class SearchDialog (GtkDialog):
-    """ Search Dialog """
+    ''' Search Dialog '''
     
     def __init__ (self, data):
 
         GtkDialog.__init__ (self)
         
-        self.set_title ('Search')
+        self.set_title (_("Search"))
         self.set_usize (400, 500)        
-        self.connect("delete_event", self.close)
+        self.connect ('delete_event', self.close)
 
-        self.data  = data
         self.pairs   = []
         
         # Buttons
         apply_b = GnomeStockButton (STOCK_PIXMAP_SEARCH)
-        apply_b.connect ("clicked", self.apply)
+        apply_b.connect ('clicked', self.apply)
 
         close_b = GnomeStockButton (STOCK_BUTTON_CLOSE)
-        close_b.connect ("clicked", self.close)
-        
+        close_b.connect ('clicked', self.close)
+
+        acc = GtkAccelGroup ()
+        self.add_accel_group (acc)
+
+        close_b.add_accelerator ('clicked', acc, GDK.Escape, 0, 0)
+        apply_b.add_accelerator ('clicked', acc, GDK.Return, 0, 0);
+
         self.action_area.add (apply_b)
         self.action_area.add (close_b)
 
@@ -147,37 +155,38 @@ class SearchDialog (GtkDialog):
         table.set_border_width (5)
         table.set_col_spacings (5)
         
-        table.attach (GtkLabel ('Field'), 0, 1, 0, 1)
-        table.attach (GtkLabel ('Pattern'), 1, 2, 0, 1)
+        table.attach (GtkLabel (_("Field")), 0, 1, 0, 1)
+        table.attach (GtkLabel (_("Pattern")), 1, 2, 0, 1)
         
         self.field = GtkCombo ()
         table.attach (self.field, 0, 1, 1, 2)
 
         self.text = GnomeEntry ('match')
         table.attach (self.text, 1, 2, 1, 2)
-        self.text.gtk_entry ().connect ("activate", self.apply)
+        self.text.gtk_entry ().connect ('activate', self.apply)
 
         # fill the combo
-        self.field.set_popdown_strings ([' - all - '] +
+        self.field.set_popdown_strings ([' - any field - '] +
                                         list (Config.get
-                                              ("base/searched").data))
-
-        self.notebook.append_page (table, GtkLabel ('Simple Search'))
+                                              ('base/searched').data) +
+                                        [' - type - ', ' - key - '])
 
+        self.notebook.append_page (table, GtkLabel (_("Simple Search")))
+        
         # extended search
         hbox = GtkHBox (spacing=5)
-        hbox.pack_start (GtkLabel ('Search command:'),
+        hbox.pack_start (GtkLabel (_("Search command:")),
                          expand=FALSE, fill=FALSE)
         self.expert = GnomeEntry ('expert-search')
-        self.expert.gtk_entry ().connect ("activate", self.apply)
+        self.expert.gtk_entry ().connect ('activate', self.apply)
         hbox.pack_start (self.expert)
         
-        self.notebook.append_page (hbox, GtkLabel ('Expert Search'))
+        self.notebook.append_page (hbox, GtkLabel (_("Expert Search")))
 
 
         # database
         self.root_tree = GtkTree ()
-        self.root_tree.connect ("selection_changed", self.selection)
+        self.root_tree.connect ('selection_changed', self.selection)
         
         holder = GtkScrolledWindow ()
         holder.set_policy (POLICY_AUTOMATIC, POLICY_AUTOMATIC)
@@ -185,19 +194,33 @@ class SearchDialog (GtkDialog):
 
         self.vbox.pack_start (holder)
 
-        self.root_item = ItemStorage ('Full database', self.data.data)
-        self.root_tree.append (self.root_item)
-
         # connect a menu to the right button
-        self.root_tree.connect ("button_press_event", self.popup_menu)
+        self.root_tree.connect ('button_press_event', self.popup_menu)
 
         self.menu = GtkMenu ()
-        self.delete_button = popup_add (self.menu, "Delete",  self.search_delete)
+        self.delete_button = popup_add (self.menu, _("Delete"),  self.search_delete)
         self.menu.show ()
 
-        self.status.push (1, 'Ready to search !')
+        self.root_item = None
+        self.create_root_item (data)
         return
 
+    def create_root_item (self, data):
+        self.data = data
+
+        if self.root_item:
+            self.root_item.remove_subtree ()
+            self.root_tree.remove (self.root_item)
+            
+        # initialize the tree with the full database
+        self.root_item = ItemStorage (_("Full database"), self.data.data)
+        self.root_tree.append (self.root_item)
+        self.root_item.show ()
+
+        self.status.pop  (1)
+        self.status.push (1, _("Ready to search !"))
+        return
+    
     
     def apply (self, widget):
         if self.data.data is None: return
@@ -208,8 +231,15 @@ class SearchDialog (GtkDialog):
         # Expert search
         if page == 1:
             
-            user_global = { 's' : Pyblio.TextUI._split_req,
-                            'has' : Pyblio.TextUI.has}
+            user_global = {
+                's'   : Pyblio.TextUI._split_req,
+                'has' : Pyblio.TextUI.has,
+                'any_has'  : Pyblio.TextUI.any_has,
+                'has_key'  : Pyblio.TextUI.has_key,
+                'has_type' : Pyblio.TextUI.has_type,
+                'before' : Pyblio.TextUI.before,
+                'after' : Pyblio.TextUI.after,
+                }
             
             search = self.expert.gtk_entry ().get_text ()
             try:
@@ -217,7 +247,7 @@ class SearchDialog (GtkDialog):
             except:
                 etype, value, tb = sys.exc_info ()
 		traceback.print_exception (etype, value, tb)
-                dialog = GnomeErrorDialog ('internal error during evaluation')
+                dialog = GnomeErrorDialog (_("internal error during evaluation"))
                 dialog.run_and_close ()
                 return
 
@@ -231,22 +261,34 @@ class SearchDialog (GtkDialog):
             if match == '': return
 
             error = 0
-            if field == ' - all - ' or field == '':
-                test = None
+
+            if field == ' - any field - ' or field == '':
+                try:
+                    test = Search.AnyTester (match)
+                except re.error, err:
+                    error = 1
+                    
                 name = 'any ~ ' + match
-                
-                for f in Config.get ("base/searched").data:
+
+            elif field == ' - type - ':
+                # get the type description
+                the_type = Types.getentry (match, 0)
+
+                if the_type is None:
+                    err = ['No such Entry type']
+                    error = 1
+                else:
                     try:
-                        new = Search.Tester (f, match)
+                        test = Search.TypeTester (the_type)
                     except re.error, err:
                         error = 1
-                        break
 
-                    if test:
-                        test = test | new
-                    else:
-                        test = new
-                    
+            elif field == ' - key - ':
+                try:
+                    test = Search.KeyTester (match)
+                except re.error, err:
+                    error = 1
+
             else:
                 try:
                     test = Search.Tester (field, match)
@@ -254,7 +296,7 @@ class SearchDialog (GtkDialog):
                     error = 1
                 
             if error:
-                dialog = GnomeErrorDialog ('while compiling %s\nerror: %s' %
+                dialog = GnomeErrorDialog (_("while compiling %s\nerror: %s") %
                                            (match, err [0]))
                 dialog.run_and_close ()
                 return
@@ -293,13 +335,13 @@ class SearchDialog (GtkDialog):
         
         if tree:
             # if we created a new subtree
-            tree.connect ("button_press_event", self.popup_menu)
+            tree.connect ('button_press_event', self.popup_menu)
             selection.expand ()
 
         selection.tree.select_child (item)
 
         self.status.pop (1)
-        self.status.push (1, 'found %d matches' % len (r))
+        self.status.push (1, _("found %d matches") % len (r))
 
         return
     
@@ -327,7 +369,7 @@ class SearchDialog (GtkDialog):
             Utils.set_cursor (self, 'normal')
             
             self.status.pop (1)
-            self.status.push (1, '%d matches in this node' % len (data))
+            self.status.push (1, _("%d matches in this node") % len (data))
             
         return
 
