@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Open.py,v 1.18 1999/09/28 07:32:20 gobry Exp $
+# $Id: Open.py,v 1.1.1.1 1999/11/22 13:29:30 fredgo Exp $
 
 
 from types import *
@@ -48,7 +48,7 @@ One can apply the following commands on the output of bibopen :
 
 
 def get_by_name (entity, method):
-	""" returns a specific field of the given entity """
+	''' returns a specific field of the given entity '''
 
 	meth = Autoload.get_by_name ("format", entity)
 	
@@ -58,7 +58,7 @@ def get_by_name (entity, method):
 	return None
 
 def get_by_regexp (entity, method):
-	""" returns a specific field of the given entity """
+	''' returns a specific field of the given entity '''
 
 	meth = Autoload.get_by_regexp ("format", entity)
 	
@@ -143,13 +143,13 @@ default, this formatting is the same as the one used by `more'
 
 
 def bibwrite (entity, out = None, how = None):
-	""" """
+	''' '''
 
 	# default output
 	out = out or sys.stdout
 	
 	def simplewrite (entry, output = sys.stdout):
-		""" Print an entry as simple text """
+		''' Print an entry as simple text '''
 		output.write (str (entry) + "\n")
 
 	
