@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Types.py,v 1.4 1999/09/30 15:21:04 gobry Exp $
+# $Id: Types.py,v 1.1.1.1 1999/11/22 13:29:30 fredgo Exp $
 
 import string
 from Pyblio import Config
@@ -30,7 +30,7 @@ TypeDate   = 3
 
 
 def getentry (entry, has_default = 1):
-	""" Returns an entry description given its name """
+	''' Returns an entry description given its name '''
 	entries = Config.get ("base/entries").data
 
 	l = string.lower (entry)
@@ -44,8 +44,8 @@ def getentry (entry, has_default = 1):
 	return None
 
 def gettype (entry, field):
-	""" Return a field type given its name and the entry it
-	belongs to """
+	''' Return a field type given its name and the entry it
+	belongs to '''
 	
 	fields = Config.get ("base/fields").data
 
@@ -60,8 +60,8 @@ def gettype (entry, field):
 	
 
 class Description:
-	""" Generic Holder for information related to Field/Entry
-	descriptions """
+	''' Generic Holder for information related to Field/Entry
+	descriptions '''
     
 	def __init__ (self, name):
 		self.name       = name
@@ -90,7 +90,7 @@ class Description:
 
 
 class FieldDescription (Description):
-	""" Available informations for a given field type """
+	''' Available informations for a given field type '''
     
 	def __init__ (self, name, type = TypeText):
         
@@ -100,7 +100,7 @@ class FieldDescription (Description):
 
     
 class EntryDescription (Description):
-	""" Informations on a given entry type """
+	''' Informations on a given entry type '''
     
 	def __init__ (self, name):
 		Description.__init__ (self, name)
