@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtex.c,v 1.22 1999/09/15 09:11:54 gobry Exp $
+ $Id: bibtex.c,v 1.1.1.1 1999/11/22 13:29:32 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -79,6 +79,7 @@ add_to_dico (gpointer key, gpointer value, gpointer user) {
     }
     
     field = (BibtexField *) value;
+    g_strdown (val);
 
     g_hash_table_insert ((GHashTable *) user, val, field->structure);
 }
@@ -141,7 +142,11 @@ bibtex_source_next_entry (BibtexSource * file,
 				bibtex_entry_destroy (ent, TRUE);
 				ent = NULL;
 			    }
-			    
+			    else {
+			        /* flatten the preamble */
+			        ent->preamble = 
+				   bibtex_struct_flatten (ent->preamble);
+			    }
 			    break;
 			}
 
