@@ -11,10 +11,11 @@ import string, os
 
 # define autoloaded formats
 
-Autoload.preregister ('format', 'BibTeX', 'Pyblio.Format.BibTeX',  'file:.*\.bib')
-Autoload.preregister ('format', 'RefDB',  'Pyblio.Format.RefDB',   'file:.*\.brf')
-Autoload.preregister ('format', 'Ovid',   'Pyblio.Format.Ovid',    'file:.*\.ovid')
-Autoload.preregister ('format', 'DocBook','Pyblio.Format.docbook', 'file:.*\.sgml')
+Autoload.preregister ('format', 'BibTeX',  'Pyblio.Format.BibTeX',  'file:.*\.bib')
+Autoload.preregister ('format', 'RefDB',   'Pyblio.Format.RefDB',   'file:.*\.brf')
+Autoload.preregister ('format', 'Ovid',    'Pyblio.Format.Ovid',    'file:.*\.ovid')
+Autoload.preregister ('format', 'Medline', 'Pyblio.Format.Medline', 'file:.*\.med')
+Autoload.preregister ('format', 'DocBook', 'Pyblio.Format.docbook', 'file:.*\.sgml')
 
 # these two are very close
 Autoload.preregister ('format', 'Refer',   'Pyblio.Format.Refer', 'file:.*\.refer')
@@ -56,7 +57,7 @@ fields = [ "CrossRef", "Key", "Author", "Address_1", "Address_2",
            "Year", "NoSeries", "ConfPlace", "ConfDate", "Cote", "IEEECN",
            "LoCN",
            "ISBN", "ISSN", "Note", "Language", "HowPublished", "To_Appear",
-           "From", "Received", "Owner", "KeyWords", "Abstract", "Remarks" ]
+           "From", "Received", "Owner", "Keywords", "Abstract", "Remarks" ]
 
 desc = {}
 # create the hash table
@@ -149,6 +150,7 @@ Config.set ("base/searched",
 
 Config.set ("base/defaulttype", ent ['article'])
 
+
 # ==================================================
 
 from Pyblio.GnomeUI import FieldsInfo
