@@ -19,18 +19,26 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybliographic.py,v 1.2 1999/08/25 11:07:40 gobry Exp $
+# $Id: pybliographic.py,v 1.1.1.1 1999/11/22 13:29:35 fredgo Exp $
 
 
 from Pyblio.GnomeUI import Pybliographic
 from gtk import *
+from Pyblio import Base, Config
+
+import os
 
 main = Pybliographic.Pybliographic (version)
 main.show ()
 
 if len (sys.argv) > 1:
-    main.open (sys.argv [1])
-
+    try:
+        full = os.path.abspath (sys.argv [1])
+    except AttributeError:
+        full = sys.argv [1]
+        
+    main.open (full)
+    
 mainloop ()
 
 
